@@ -41,7 +41,7 @@ class StaticxGenerator:
         # Temporary output file (bootloader copy)
         self.tmpoutput = None
         self.tmpprog = None
-        self.tmpdir = None
+        self.tmpdir = mkdtemp(prefix='staticx-archive-')
 
         f = NamedTemporaryFile(prefix='staticx-archive-', suffix='.tar')
         self.sxar = SxArchive(fileobj=f, mode='w', compress=self.compress)
@@ -130,7 +130,6 @@ class StaticxGenerator:
 
 
         # Build the archive to be appended
-        self.tmpdir = mkdtemp(prefix='staticx-archive-')
         with self.sxar as ar:
             run_hooks(self)
 
@@ -223,11 +222,19 @@ class StaticxGenerator:
         while islink(libpath):
             arcname = basename(libpath)
             libpath = get_symlink_target(libpath)
+            target = basename(libpath)
+
+            # Skip symlinks that point to a file with the same name but in a
+            # different path. We strip path info (and keep just basenames) so
+            # this would be self-referential.
+            if arcname == target:
+                continue
 
             # Add a symlink.
             # At this point the target probably doesn't exist, but that doesn't matter yet.
-            logging.info("Adding Symlink {} => {}".format(arcname, basename(libpath)))
-            self.sxar.add_symlink(arcname, basename(libpath))
+            logging.info("Adding Symlink {} => {}".format(arcname, target))
+            self.sxar.add_symlink(arcname, target)
+
             if arcname in self._added_libs:
                 raise InternalError("libname {} absent from _added_libs but"
                         " symlink {} present".format(libname, arcname))
